============
pseudopeople
============

pseudopeople is a Python package that generates realistic simulated data about a
fictional United States population, designed for use in testing entity resolution
(record linkage) methods or other data science algorithms at scale.

**pseudopeople requires Python 3.10-3.11 to run**

You can install pseudopeople from PyPI with pip:

  ``> pip install pseudopeople``

or build it from source with

  ``> git clone https://github.com/ihmeuw/pseudopeople.git``

  ``> cd pseudopeople``

  ``> python setup.py install``

Documentation
======================
You can view documentation at https://pseudopeople.readthedocs.io/en/latest/

To receive updates about this software package `join the mailing list
here
<https://mailman11.u.washington.edu/mailman/listinfo/pseudopeople-users>`_.
